import { DeliveryClientConfig } from '../config/delivery-client.config';
import { IContentItem } from '../interfaces/item/icontent-item.interface';
import { IItemQueryConfig } from '../interfaces/item/iitem-query.config';
import { CloudResponseDebug } from '../models/common/cloud-response-debug.class';
import { ElementResponses } from '../models/element/responses';
import { ItemResponses } from '../models/item/responses';
import { TaxonomyResponses } from '../models/taxonomy/responses';
import { TypeResponses } from '../models/type/responses';
import { BaseResponse } from '../services/http/base-response.class';
export declare class ResponseMapService {
    /**
     * Service used to map content types
     */
    private readonly typeMapService;
    /**
     * Service used to map content items
     */
    private readonly itemMapService;
    /**
     * Service used to map taxonomies
     */
    private readonly taxonomyMapService;
    /**
     * Services used to map elements
     */
    private readonly elementMapService;
    constructor(config: DeliveryClientConfig);
    /**
     * Gets response for getting a single type
     * @param response Response data
     */
    mapSingleTypeResponse(response: BaseResponse): TypeResponses.DeliveryTypeResponse;
    /**
     * Gets resposne for getting multiple types
     * @param response Response data
     * @param options Options
     */
    mapMultipleTypeResponse(response: BaseResponse): TypeResponses.DeliveryTypeListingResponse;
    /**
     * Gets response for getting single item
     * @param response Response data
     * @param queryConfig Query configuration
     */
    mapSingleResponse<TItem extends IContentItem>(response: BaseResponse, queryConfig: IItemQueryConfig): ItemResponses.DeliveryItemResponse<TItem>;
    /**
     * Gets response for getting multiple items
     * @param response Response data
     * @param queryConfig Query configuration
     */
    mapMultipleResponse<TItem extends IContentItem>(response: BaseResponse, queryConfig: IItemQueryConfig): ItemResponses.DeliveryItemListingResponse<TItem>;
    /**
     * Gets response for getting single taxonomy item
     * @param response Response data
     */
    mapTaxonomyResponse(response: BaseResponse): TaxonomyResponses.TaxonomyResponse;
    /**
     * Gets response for getting multiples taxonomies
     * @param response Response data
     */
    mapTaxonomiesResponse(response: BaseResponse): TaxonomyResponses.TaxonomiesResponse;
    /**
    * Gets response for getting single content type element
    * @param response Response data
    */
    mapElementResponse(response: BaseResponse): ElementResponses.ElementResponse;
    mapResponseDebug(response: BaseResponse): CloudResponseDebug;
}
