import { packageId, repoHost, version } from '../library-version';
import { ElementQuery } from '../query/element/element-query.class';
import { MultipleItemQuery } from '../query/item/multiple-item-query.class';
import { SingleItemQuery } from '../query/item/single-item-query.class';
import { TaxonomiesQuery } from '../query/taxonomy/taxonomies-query.class';
import { TaxonomyQuery } from '../query/taxonomy/taxonomy-query.class';
import { MultipleTypeQuery } from '../query/type/multiple-type-query.class';
import { SingleTypeQuery } from '../query/type/single-type-query.class';
import { HttpService } from '../services/http/http.service';
import { QueryService } from '../services/query.service';
var DeliveryClient = /** @class */ (function () {
    /**
    * Delivery client used to fetch data from Kentico Cloud
    * @constructor
    * @param {DeliveryClientConfig} config - The client configuration
    */
    function DeliveryClient(config) {
        this.config = config;
        this.queryService = new QueryService(config, new HttpService(), {
            host: repoHost,
            name: packageId,
            version: version
        });
    }
    /**
    * Gets query for multiple types
    */
    DeliveryClient.prototype.types = function () {
        return new MultipleTypeQuery(this.config, this.queryService);
    };
    /**
    * Gets query for single type
    * @param {string} typeCodename - Codename of the type to fetch
    */
    DeliveryClient.prototype.type = function (typeCodename) {
        return new SingleTypeQuery(this.config, this.queryService, typeCodename);
    };
    /**
    * Gets query for multiple items
    */
    DeliveryClient.prototype.items = function () {
        return new MultipleItemQuery(this.config, this.queryService);
    };
    /**
    * Gets query for single item
    * @param {string} codename - Codename of item to fetch
    */
    DeliveryClient.prototype.item = function (codename) {
        return new SingleItemQuery(this.config, this.queryService, codename);
    };
    /**
    * Gets query for single taxonomy
    * @param {string} codename - Codename of taxonomy to fetch
    */
    DeliveryClient.prototype.taxonomy = function (codename) {
        return new TaxonomyQuery(this.config, this.queryService, codename);
    };
    /**
    * Gets query for multiple taxonomies
    */
    DeliveryClient.prototype.taxonomies = function () {
        return new TaxonomiesQuery(this.config, this.queryService);
    };
    /**
     * Gets query for an element within a type
     * @param {string} typeCodename - Codename of the type
     * @param {string} elementCodename - Codename of the element
     */
    DeliveryClient.prototype.element = function (typeCodename, elementCodename) {
        return new ElementQuery(this.config, this.queryService, typeCodename, elementCodename);
    };
    return DeliveryClient;
}());
export { DeliveryClient };
//# sourceMappingURL=delivery-client.js.map