var DeliveryClientConfig = /** @class */ (function () {
    /**
    * Configuration of Kentico Cloud Delivery client
    * @constructor
    * @param {FieldType} projectId - ProjectId of your Kentico Cloud project
    * @param {TypeResolver[]} typeResolvers - List of resolvers that are used to create strongly typed objects from Kentico Cloud response
    * @param {boolean} enableAdvancedLogging - Indicates if advanced (developer's) issues are logged in console. Enable for development and disable in production.
    * @param {string} previewApiKey - Preview API key used to get unpublished content items
    * @param {boolean} enablePreviewMode - Indicates if preview mode is enabled globally. This can be overriden on query level
    * @param {string} defaultLanguage - Sets default language that will be used for all queries unless overriden with query parameters
    * @param {string} baseUrl - Can be used to configure custom base url
    * @param {string} basePreviewUrl - Can be used to configure custom preview url
    * @param {string} securedApiKey - Secured API key: Use secured API only when running on Node.JS server, otherwise you can expose your key
    * @param {boolean} enableSecuredMode - Indicates if secured mode is enabled globally. This can be overriden on query level
    * @param {retryAttempts} retryAttempts - Number of retry attempts when error occures
    */
    function DeliveryClientConfig(projectId, typeResolvers, options) {
        this.projectId = projectId;
        this.typeResolvers = typeResolvers;
        this.options = options;
        /**
        * Indicates if advanced (developer's) issues are logged in console. Enable for development and disable in production
        */
        this.enableAdvancedLogging = true;
        /**
        * Indicates if preview mode is enabled globally
        */
        this.enablePreviewMode = false;
        /**
       * Indicates if secured mode is enabled globally
       */
        this.enableSecuredMode = false;
        if (!projectId) {
            throw Error("Cannot create delivery configuration without 'projectId'");
        }
        if (!typeResolvers) {
            throw Error("Cannot create delivery configuration without specifying 'typeResolvers'");
        }
        if (options) {
            Object.assign(this, options);
        }
    }
    return DeliveryClientConfig;
}());
export { DeliveryClientConfig };
//# sourceMappingURL=delivery-client.config.js.map