import { TaxonomySystemAttributes } from '../models/taxonomy/taxonomy-system-attributes.class';
import { TaxonomyTerms } from '../models/taxonomy/taxonomy-terms.class';
import { TaxonomyGroup } from '../models/taxonomy/taxonomy-group.class';
var TaxonomyMapService = /** @class */ (function () {
    function TaxonomyMapService() {
    }
    TaxonomyMapService.prototype.mapTaxonomy = function (taxonomySystem, taxonomyTerms) {
        if (!taxonomySystem) {
            throw Error("Cannot map taxonomy due to missing 'system' property");
        }
        if (!taxonomyTerms) {
            throw Error("Cannot map taxonomy due to missing 'terms' property");
        }
        if (!Array.isArray(taxonomyTerms)) {
            throw Error("Cannot map terms because no terms array was provided");
        }
        var mappedSystemAttributes = new TaxonomySystemAttributes(taxonomySystem.id, taxonomySystem.name, taxonomySystem.codename, taxonomySystem.last_modified);
        var mappedTerms = this.mapTaxonomyTerms(taxonomyTerms);
        return new TaxonomyGroup(mappedSystemAttributes, mappedTerms);
    };
    TaxonomyMapService.prototype.mapTaxonomies = function (taxonomies) {
        var _this = this;
        if (!taxonomies) {
            throw Error("Cannot map taxonomy due to missing 'taxonomies' property");
        }
        if (!Array.isArray(taxonomies)) {
            throw Error("Cannot map taxonomies because the 'taxonomies' property is not an array ");
        }
        var mappedTaxonomies = [];
        taxonomies.forEach(function (taxonomy) {
            mappedTaxonomies.push(_this.mapTaxonomy(taxonomy.system, taxonomy.terms));
        });
        return mappedTaxonomies;
    };
    /**
     * Recursively map array of taxonomy terms
     * @param termsArray Terms array to map
     */
    TaxonomyMapService.prototype.mapTaxonomyTerms = function (termsArray) {
        var _this = this;
        if (termsArray.length === 0) {
            return [];
        }
        var mappedTermsArray = [];
        termsArray.forEach(function (terms) {
            var mappedTerms = new TaxonomyTerms(terms.name, terms.codename, _this.mapTaxonomyTerms(terms.terms));
            mappedTermsArray.push(mappedTerms);
        });
        return mappedTermsArray;
    };
    return TaxonomyMapService;
}());
export { TaxonomyMapService };
//# sourceMappingURL=taxonomy-map.service.js.map