import { DeliveryClientConfig } from '../config/delivery-client.config';
import { IContentItem } from '../interfaces/item/icontent-item.interface';
import { ElementQuery } from '../query/element/element-query.class';
import { MultipleItemQuery } from '../query/item/multiple-item-query.class';
import { SingleItemQuery } from '../query/item/single-item-query.class';
import { TaxonomiesQuery } from '../query/taxonomy/taxonomies-query.class';
import { TaxonomyQuery } from '../query/taxonomy/taxonomy-query.class';
import { MultipleTypeQuery } from '../query/type/multiple-type-query.class';
import { SingleTypeQuery } from '../query/type/single-type-query.class';
import { IDeliveryClient } from './idelivery-client.interface';
export declare class DeliveryClient implements IDeliveryClient {
    protected config: DeliveryClientConfig;
    private queryService;
    /**
    * Delivery client used to fetch data from Kentico Cloud
    * @constructor
    * @param {DeliveryClientConfig} config - The client configuration
    */
    constructor(config: DeliveryClientConfig);
    /**
    * Gets query for multiple types
    */
    types(): MultipleTypeQuery;
    /**
    * Gets query for single type
    * @param {string} typeCodename - Codename of the type to fetch
    */
    type(typeCodename: string): SingleTypeQuery;
    /**
    * Gets query for multiple items
    */
    items<TItem extends IContentItem>(): MultipleItemQuery<TItem>;
    /**
    * Gets query for single item
    * @param {string} codename - Codename of item to fetch
    */
    item<TItem extends IContentItem>(codename: string): SingleItemQuery<TItem>;
    /**
    * Gets query for single taxonomy
    * @param {string} codename - Codename of taxonomy to fetch
    */
    taxonomy<TItem extends IContentItem>(codename: string): TaxonomyQuery;
    /**
    * Gets query for multiple taxonomies
    */
    taxonomies<TItem extends IContentItem>(): TaxonomiesQuery;
    /**
     * Gets query for an element within a type
     * @param {string} typeCodename - Codename of the type
     * @param {string} elementCodename - Codename of the element
     */
    element(typeCodename: string, elementCodename: string): ElementQuery;
}
