"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var library_version_1 = require("../library-version");
var element_query_class_1 = require("../query/element/element-query.class");
var multiple_item_query_class_1 = require("../query/item/multiple-item-query.class");
var single_item_query_class_1 = require("../query/item/single-item-query.class");
var taxonomies_query_class_1 = require("../query/taxonomy/taxonomies-query.class");
var taxonomy_query_class_1 = require("../query/taxonomy/taxonomy-query.class");
var multiple_type_query_class_1 = require("../query/type/multiple-type-query.class");
var single_type_query_class_1 = require("../query/type/single-type-query.class");
var http_service_1 = require("../services/http/http.service");
var query_service_1 = require("../services/query.service");
var DeliveryClient = /** @class */ (function () {
    /**
    * Delivery client used to fetch data from Kentico Cloud
    * @constructor
    * @param {DeliveryClientConfig} config - The client configuration
    */
    function DeliveryClient(config) {
        this.config = config;
        this.queryService = new query_service_1.QueryService(config, new http_service_1.HttpService(), {
            host: library_version_1.repoHost,
            name: library_version_1.packageId,
            version: library_version_1.version
        });
    }
    /**
    * Gets query for multiple types
    */
    DeliveryClient.prototype.types = function () {
        return new multiple_type_query_class_1.MultipleTypeQuery(this.config, this.queryService);
    };
    /**
    * Gets query for single type
    * @param {string} typeCodename - Codename of the type to fetch
    */
    DeliveryClient.prototype.type = function (typeCodename) {
        return new single_type_query_class_1.SingleTypeQuery(this.config, this.queryService, typeCodename);
    };
    /**
    * Gets query for multiple items
    */
    DeliveryClient.prototype.items = function () {
        return new multiple_item_query_class_1.MultipleItemQuery(this.config, this.queryService);
    };
    /**
    * Gets query for single item
    * @param {string} codename - Codename of item to fetch
    */
    DeliveryClient.prototype.item = function (codename) {
        return new single_item_query_class_1.SingleItemQuery(this.config, this.queryService, codename);
    };
    /**
    * Gets query for single taxonomy
    * @param {string} codename - Codename of taxonomy to fetch
    */
    DeliveryClient.prototype.taxonomy = function (codename) {
        return new taxonomy_query_class_1.TaxonomyQuery(this.config, this.queryService, codename);
    };
    /**
    * Gets query for multiple taxonomies
    */
    DeliveryClient.prototype.taxonomies = function () {
        return new taxonomies_query_class_1.TaxonomiesQuery(this.config, this.queryService);
    };
    /**
     * Gets query for an element within a type
     * @param {string} typeCodename - Codename of the type
     * @param {string} elementCodename - Codename of the element
     */
    DeliveryClient.prototype.element = function (typeCodename, elementCodename) {
        return new element_query_class_1.ElementQuery(this.config, this.queryService, typeCodename, elementCodename);
    };
    return DeliveryClient;
}());
exports.DeliveryClient = DeliveryClient;
//# sourceMappingURL=delivery-client.js.map