import { Observable } from 'rxjs/Observable';
import { DeliveryClientConfig } from '../../config/delivery-client.config';
import { IHeader } from '../../interfaces/common/iheader.interface';
import { ITaxonomyQueryConfig } from '../../interfaces/taxonomy/itaxonomy-query.config';
import { TaxonomyResponses } from '../../models/taxonomy/responses';
import { QueryService } from '../../services/query.service';
import { BaseQuery } from '../common/base-query.class';
export declare abstract class BaseTaxonomyQuery<TResponse> extends BaseQuery<TResponse> {
    protected config: DeliveryClientConfig;
    protected queryService: QueryService;
    /**
     * Taxonomies endpoint URL action
     */
    protected readonly taxonomiesEndpoint: string;
    /**
     * Query configuration
     */
    protected _queryConfig: ITaxonomyQueryConfig;
    constructor(config: DeliveryClientConfig, queryService: QueryService);
    /**
     * Used to configure query
     * @param queryConfig Query configuration
     */
    queryConfig(queryConfig: ITaxonomyQueryConfig): this;
    /**
     * Gets headers used by this query
     */
    getHeaders(): IHeader[];
    protected getTaxonomyQueryUrl(taxonomyCodename: string): string;
    protected getTaxonomiesQueryUrl(): string;
    protected runTaxonomyQuery(codename: string): Observable<TaxonomyResponses.TaxonomyResponse>;
    protected runTaxonomiesQuery(): Observable<TaxonomyResponses.TaxonomiesResponse>;
}
