"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var field_map_service_1 = require("./field-map.service");
var ItemMapService = /** @class */ (function () {
    function ItemMapService(config) {
        this.config = config;
        this.fieldMapService = new field_map_service_1.FieldMapService(config);
    }
    ItemMapService.prototype.mapItem = function (item, modularContent, queryConfig) {
        if (item == null) {
            throw Error("Could not map item because its undefined");
        }
        return this.fieldMapService.mapFields(item, modularContent, queryConfig, []);
    };
    /**
     * Maps single item to its proper strongly typed model from the given Cloud response
     * @param response Cloud response used to map the item
     * @param queryConfig Query configuration
     */
    ItemMapService.prototype.mapSingleItem = function (response, queryConfig) {
        return this.mapItem(response.item, response.modular_content, queryConfig);
    };
    /**
    * Maps multiple items to their strongly typed model from the given Cloud response
    * @param response Cloud response used to map the item
    * @param queryConfig Query configuration
    */
    ItemMapService.prototype.mapMultipleItems = function (response, queryConfig) {
        var that = this;
        return response.items.map(function (item) {
            return that.mapItem(item, response.modular_content, queryConfig);
        });
    };
    return ItemMapService;
}());
exports.ItemMapService = ItemMapService;
//# sourceMappingURL=item-map.service.js.map