"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var cloud_response_debug_class_1 = require("../models/common/cloud-response-debug.class");
var pagination_class_1 = require("../models/common/pagination.class");
var responses_1 = require("../models/element/responses");
var responses_2 = require("../models/item/responses");
var responses_3 = require("../models/taxonomy/responses");
var responses_4 = require("../models/type/responses");
var element_map_service_1 = require("./element-map.service");
var item_map_service_1 = require("./item-map.service");
var taxonomy_map_service_1 = require("./taxonomy-map.service");
var type_map_service_1 = require("./type-map.service");
var ResponseMapService = /** @class */ (function () {
    function ResponseMapService(config) {
        this.typeMapService = new type_map_service_1.TypeMapService();
        this.itemMapService = new item_map_service_1.ItemMapService(config);
        this.taxonomyMapService = new taxonomy_map_service_1.TaxonomyMapService();
        this.elementMapService = new element_map_service_1.ElementMapService();
    }
    /**
     * Gets response for getting a single type
     * @param response Response data
     */
    ResponseMapService.prototype.mapSingleTypeResponse = function (response) {
        var cloudResponse = response.data;
        // map type
        var type = this.typeMapService.mapSingleType(cloudResponse);
        return new responses_4.TypeResponses.DeliveryTypeResponse(type, this.mapResponseDebug(response));
    };
    /**
     * Gets resposne for getting multiple types
     * @param response Response data
     * @param options Options
     */
    ResponseMapService.prototype.mapMultipleTypeResponse = function (response) {
        var cloudResponse = response.data;
        // map types
        var types = this.typeMapService.mapMultipleTypes(cloudResponse);
        // pagination
        var pagination = new pagination_class_1.Pagination(cloudResponse.pagination.skip, cloudResponse.pagination.limit, cloudResponse.pagination.count, cloudResponse.pagination.next_page);
        return new responses_4.TypeResponses.DeliveryTypeListingResponse(types, pagination, this.mapResponseDebug(response));
    };
    /**
     * Gets response for getting single item
     * @param response Response data
     * @param queryConfig Query configuration
     */
    ResponseMapService.prototype.mapSingleResponse = function (response, queryConfig) {
        var cloudResponse = response.data;
        // map item
        var item = this.itemMapService.mapSingleItem(cloudResponse, queryConfig);
        return new responses_2.ItemResponses.DeliveryItemResponse(item, this.mapResponseDebug(response));
    };
    /**
     * Gets response for getting multiple items
     * @param response Response data
     * @param queryConfig Query configuration
     */
    ResponseMapService.prototype.mapMultipleResponse = function (response, queryConfig) {
        var cloudResponse = response.data;
        // map items
        var items = this.itemMapService.mapMultipleItems(cloudResponse, queryConfig);
        // pagination
        var pagination = new pagination_class_1.Pagination(cloudResponse.pagination.skip, cloudResponse.pagination.limit, cloudResponse.pagination.count, cloudResponse.pagination.next_page);
        return new responses_2.ItemResponses.DeliveryItemListingResponse(items, pagination, this.mapResponseDebug(response));
    };
    /**
     * Gets response for getting single taxonomy item
     * @param response Response data
     */
    ResponseMapService.prototype.mapTaxonomyResponse = function (response) {
        var cloudResponse = response.data;
        // map taxonomy
        var taxonomy = this.taxonomyMapService.mapTaxonomy(cloudResponse.system, cloudResponse.terms);
        return new responses_3.TaxonomyResponses.TaxonomyResponse(taxonomy, this.mapResponseDebug(response));
    };
    /**
     * Gets response for getting multiples taxonomies
     * @param response Response data
     */
    ResponseMapService.prototype.mapTaxonomiesResponse = function (response) {
        var cloudResponse = response.data;
        // map taxonomies
        var taxonomies = this.taxonomyMapService.mapTaxonomies(cloudResponse.taxonomies);
        // pagination
        var pagination = new pagination_class_1.Pagination(cloudResponse.pagination.skip, cloudResponse.pagination.limit, cloudResponse.pagination.count, cloudResponse.pagination.next_page);
        return new responses_3.TaxonomyResponses.TaxonomiesResponse(taxonomies, pagination, this.mapResponseDebug(response));
    };
    /**
    * Gets response for getting single content type element
    * @param response Response data
    */
    ResponseMapService.prototype.mapElementResponse = function (response) {
        var cloudResponse = response.data;
        // map element
        var element = this.elementMapService.mapElement(cloudResponse);
        return new responses_1.ElementResponses.ElementResponse(element, this.mapResponseDebug(response));
    };
    ResponseMapService.prototype.mapResponseDebug = function (response) {
        if (!response) {
            throw Error("Cannot map 'debug' model from the response");
        }
        return new cloud_response_debug_class_1.CloudResponseDebug(response.response);
    };
    return ResponseMapService;
}());
exports.ResponseMapService = ResponseMapService;
//# sourceMappingURL=response-map.service.js.map