"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var taxonomy_system_attributes_class_1 = require("../models/taxonomy/taxonomy-system-attributes.class");
var taxonomy_terms_class_1 = require("../models/taxonomy/taxonomy-terms.class");
var taxonomy_group_class_1 = require("../models/taxonomy/taxonomy-group.class");
var TaxonomyMapService = /** @class */ (function () {
    function TaxonomyMapService() {
    }
    TaxonomyMapService.prototype.mapTaxonomy = function (taxonomySystem, taxonomyTerms) {
        if (!taxonomySystem) {
            throw Error("Cannot map taxonomy due to missing 'system' property");
        }
        if (!taxonomyTerms) {
            throw Error("Cannot map taxonomy due to missing 'terms' property");
        }
        if (!Array.isArray(taxonomyTerms)) {
            throw Error("Cannot map terms because no terms array was provided");
        }
        var mappedSystemAttributes = new taxonomy_system_attributes_class_1.TaxonomySystemAttributes(taxonomySystem.id, taxonomySystem.name, taxonomySystem.codename, taxonomySystem.last_modified);
        var mappedTerms = this.mapTaxonomyTerms(taxonomyTerms);
        return new taxonomy_group_class_1.TaxonomyGroup(mappedSystemAttributes, mappedTerms);
    };
    TaxonomyMapService.prototype.mapTaxonomies = function (taxonomies) {
        var _this = this;
        if (!taxonomies) {
            throw Error("Cannot map taxonomy due to missing 'taxonomies' property");
        }
        if (!Array.isArray(taxonomies)) {
            throw Error("Cannot map taxonomies because the 'taxonomies' property is not an array ");
        }
        var mappedTaxonomies = [];
        taxonomies.forEach(function (taxonomy) {
            mappedTaxonomies.push(_this.mapTaxonomy(taxonomy.system, taxonomy.terms));
        });
        return mappedTaxonomies;
    };
    /**
     * Recursively map array of taxonomy terms
     * @param termsArray Terms array to map
     */
    TaxonomyMapService.prototype.mapTaxonomyTerms = function (termsArray) {
        var _this = this;
        if (termsArray.length === 0) {
            return [];
        }
        var mappedTermsArray = [];
        termsArray.forEach(function (terms) {
            var mappedTerms = new taxonomy_terms_class_1.TaxonomyTerms(terms.name, terms.codename, _this.mapTaxonomyTerms(terms.terms));
            mappedTermsArray.push(mappedTerms);
        });
        return mappedTermsArray;
    };
    return TaxonomyMapService;
}());
exports.TaxonomyMapService = TaxonomyMapService;
//# sourceMappingURL=taxonomy-map.service.js.map