"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var content_type_class_1 = require("../models/type/content-type.class");
var content_type_system_attributes_class_1 = require("../models/type/content-type-system-attributes.class");
var element_class_1 = require("../models/element/element.class");
var element_option_class_1 = require("../models/element/element-option.class");
var TypeMapService = /** @class */ (function () {
    function TypeMapService() {
    }
    TypeMapService.prototype.mapType = function (type) {
        if (!type) {
            throw Error("Cannot map type");
        }
        if (!type.elements) {
            throw Error("Cannot map type elements");
        }
        var typeSystem = new content_type_system_attributes_class_1.ContentTypeSystemAttributes(type.system.id, type.system.name, type.system.codename, type.system.last_modified);
        var elements = [];
        var elementNames = Object.getOwnPropertyNames(type.elements);
        elementNames.forEach(function (elementName) {
            var typeElement = type.elements[elementName];
            if (!typeElement) {
                throw Error("Cannot find element '" + elementName + "' on type '" + type + "'");
            }
            // use json property as a codename of the type element
            var elementCodename = elementName;
            // extra properties for certain field types
            var taxonomyGroup = typeElement.taxonomy_group;
            var options = [];
            // some elements can contain options
            var rawOptions = typeElement.options;
            if (rawOptions) {
                if (!Array.isArray(rawOptions)) {
                    throw Error("Content type 'options' property has to be an array");
                }
                rawOptions.forEach(function (rawOption) {
                    options.push(new element_option_class_1.ElementOption(rawOption.name, rawOption.codename));
                });
            }
            elements.push(new element_class_1.Element(elementCodename, typeElement.type, typeElement.name, taxonomyGroup, options));
        });
        return new content_type_class_1.ContentType(typeSystem, elements);
    };
    TypeMapService.prototype.mapSingleType = function (response) {
        return this.mapType(response);
    };
    TypeMapService.prototype.mapMultipleTypes = function (response) {
        var that = this;
        return response.types.map(function (type) {
            return that.mapType(type);
        });
    };
    return TypeMapService;
}());
exports.TypeMapService = TypeMapService;
//# sourceMappingURL=type-map.service.js.map