"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var content_item_class_1 = require("../models/item/content-item.class");
var content_item_system_attributes_1 = require("../models/item/content-item-system-attributes");
var TypeResolverService = /** @class */ (function () {
    function TypeResolverService(config) {
        this.config = config;
    }
    /**
     * Indicates if given type has a type resolver
     * @param type Type
     */
    TypeResolverService.prototype.hasTypeResolver = function (type) {
        return !(!this.config.typeResolvers.find(function (m) { return m.type === type; }));
    };
    /**
     * Creates non generic ContentItem used when content type does not have a strongly typed model
     */
    TypeResolverService.prototype.createContentItem = function (item) {
        var contentItem = new content_item_class_1.ContentItem();
        // use typed 'system' property
        contentItem.system = new content_item_system_attributes_1.ContentItemSystemAttributes(item.system.id, item.system.name, item.system.codename, item.system.type, item.system.last_modified, item.system.language, item.system.sitemap_locations);
        return contentItem;
    };
    /**
     * Takes given type name and creates a strongly typed model based specified in client configuration
     * @param type Type of the content item
     * @param item Typed content item
     */
    TypeResolverService.prototype.createTypedObj = function (type, item) {
        var typedItem = this.createEmptyTypedObj(type);
        // use typed 'system' property
        typedItem.system = new content_item_system_attributes_1.ContentItemSystemAttributes(item.system.id, item.system.name, item.system.codename, item.system.type, item.system.last_modified, item.system.language, item.system.sitemap_locations);
        return typedItem;
    };
    /**
     * Creates empty typed object of given type
     * @param type Type of the content item
     */
    TypeResolverService.prototype.createEmptyTypedObj = function (type) {
        if (!type) {
            throw Error('Cannot resolve type because no type name was provided');
        }
        var typeResolver = this.config.typeResolvers.find(function (m) { return m.type === type; });
        if (!typeResolver) {
            throw Error("Cannot find resolver for type '" + type + "'. This error means that no class was registered as TypeResolver for this type. Caller of this method should first check if type is available.");
        }
        return typeResolver.resolve();
    };
    return TypeResolverService;
}());
exports.TypeResolverService = TypeResolverService;
//# sourceMappingURL=type-resolver.service.js.map